==> ulyxex.0.0.6.with-tinyMce.zip: pages/code/admin_page_modify.php <==
<?php
class PageModify extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function cat_params($id) {
		$query = "SELECT * FROM ".PAGES." WHERE ID=".$id;
		$query = $this->q($query);
		$result = mysql_fetch_assoc($query);
		return $result;
	}
	public function userPages() {
		$siteDat = $this->home_params();
		$queryLevel2 = 	"SELECT ".PAGES.".ID,".PAGES.".NAME FROM ".PAGES.",".USERPAGES.
						" WHERE ".USERPAGES.".USERID = ".$_SESSION['userid']." AND ".
						USERPAGES.".PAGEID = ".PAGES.".ID ORDER BY ".PAGES.".NAME";
						
		$queryLevel1 = 	"SELECT ID,NAME FROM ".PAGES." ORDER BY NAME";
		
		if ($_SESSION['level'] > 1) {
			$query = $this->q($queryLevel2);
		} else {
			$query = $this->q($queryLevel1);
		}
		$elements = array();
		while ( $line = mysql_fetch_assoc($query) ) {
			if ($line['ID'] == $siteDat['PAGEID']) {
				$elements[$line['NAME']." (home)"] = $line['ID'];
			} else {
				$elements[$line['NAME']] = $line['ID'];
			}
		}
		if (count($elements)) {
			$h = New Html();
			$menu = $this->h->select($elements,"cat",$siteDat['PAGEID'])." ".$this->h->input("submit",null,"GO");
			$result = $this->h->form($this->tr->ws("modify").$menu,"pages","post","admin.php?action=modify_page");
			return $result;
		}
	}
	public function update_page($catId) {
		$hide = (isset($_POST['hide']))?1:0;
		$query = "UPDATE ".PAGES." SET NAME = '".$this->h->safe($_POST['name'])."',".
									"DESCRIPTION = '".$this->h->safe($_POST['description'])."',".
									"HIDE = '".$hide."'".
									" WHERE ID = ".$catId;
		$query = $this->q($query);
		$result = $this->h->h3($this->tr->w("page updated !"));
		return $result;
	}
	public function data_page($catId) {
		$queryLevel1 = 	"SELECT ".PAGES.".* FROM ".PAGES." WHERE ID = ".$catId;
		$queryLevel2 = 	"SELECT ".PAGES.".* FROM ".PAGES.",".USERPAGES." WHERE ".
						USERPAGES.".USERID = ".$_SESSION['userid']." AND ".
						USERPAGES.".PAGEID = ".PAGES.".ID"." AND ".
						PAGES.".ID = ".$catId;

		if ($_SESSION['level'] > 1) {
			$query = $this->q($queryLevel2);
		} else {
			$query = $this->q($queryLevel1);
		}
		if ($query) {
			$dat = mysql_fetch_assoc($query);
			$sandboxParams = "";
			if ($dat['NAME'] == "SANDBOX") {
				$sandboxParams = "readonly";
			}
			$content = $this->h->input("hidden","cat",$dat['ID']);
			$content .= $this->h->input("hidden","update",1);
			$params =  ($dat['HIDE'])?" checked=\"checked\"":null;
			$content .= $this->h->p($this->tr->w("hide").$this->h->input("checkbox","hide","on",$params));
			$content .= $this->h->p($this->tr->w("title")).$this->h->p($this->h->input("text","name",$dat['NAME'],$sandboxParams." size=".FIELDWIDTH));
			$content .= $this->h->p($this->tr->w("description")).$this->h->p($this->h->textarea($dat['DESCRIPTION'],"description",array(8,FIELDWIDTH)));
			$content .= $this->h->p($this->h->input("submit","save",$this->tr->w("update")));
			$result = $this->h->form($content,"page","post","admin.php?action=modify_page");
			return $result;
		}
	}
}
?>

==> ulyxex.0.0.7.with-tinyMce.zip: pages/code/admin_page_modify.php <==
<?php
class PageModify extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
        $this->tree = New Tree();
	}
	public function cat_params($id) {
		$query = "SELECT * FROM ".PAGES." WHERE ID=".$id;
		$query = $this->q($query);
		$result = mysql_fetch_assoc($query);
		return $result;
	}
	public function userPages() {
		$siteDat = $this->home_params();
		$queryLevel2 = 	"SELECT ".PAGES.".ID,".PAGES.".NAME FROM ".PAGES.",".USERPAGES.
						" WHERE ".USERPAGES.".USERID = ".$_SESSION['userid']." AND ".
						USERPAGES.".PAGEID = ".PAGES.".ID ORDER BY ".PAGES.".NAME";
						
		$queryLevel1 = 	"SELECT ID,NAME FROM ".PAGES." ORDER BY NAME";
		
		if ($_SESSION['level'] > 1) {
			$query = $this->q($queryLevel2);
		} else {
			$query = $this->q($queryLevel1);
		}
		$elements = array();
		while ( $line = mysql_fetch_assoc($query) ) {
			if ($line['ID'] == $siteDat['PAGEID']) {
				$elements[$line['NAME']." (home)"] = $line['ID'];
			} else {
				$elements[$line['NAME']] = $line['ID'];
			}
		}
		if (count($elements)) {
			$menu = $this->h->select($elements,"cat",$siteDat['PAGEID'])." ".$this->h->input("submit",null,"GO");
			$result = $this->h->form($this->tr->ws("modify").$menu,"pages","post","admin.php?action=modify_page");
			return $result;
		}
	}
	public function update_page($pageId) {
		$hide = (isset($_POST['hide']))?1:0;
		$query = "UPDATE ".PAGES." SET NAME = '".$this->h->safe($_POST['name'])."',".
                                    "PARENTID = '".$this->h->num($_POST['parent'])."',".
									"DESCRIPTION = '".$this->h->safe($_POST['description'])."',".
									"HIDE = '".$hide."'".
									" WHERE ID = ".$pageId;
		if ($this->tree->pathsTest($page=$pageId,$parent=$_POST['parent'])) {
			$query = $this->q($query);
			$result = $this->h->h3($this->tr->w("updated !"));
		} else {
			$result = $this->h->h3($this->tr->w("bad lineage !"));
		}
		return $result;
	}
	public function data_page($pageId) {
		$queryLevel1 = 	"SELECT ".PAGES.".* FROM ".PAGES." WHERE ID = ".$pageId;
		$queryLevel2 = 	"SELECT ".PAGES.".* FROM ".PAGES.",".USERPAGES." WHERE ".
						USERPAGES.".USERID = ".$_SESSION['userid']." AND ".
						USERPAGES.".PAGEID = ".PAGES.".ID"." AND ".
						PAGES.".ID = ".$pageId;

		if ($_SESSION['level'] > 1) {
			$query = $this->q($queryLevel2);
		} else {
			$query = $this->q($queryLevel1);
		}
		if ($query) {
			$dat = mysql_fetch_assoc($query);
			$sandboxParams = "";
			if ($dat['NAME'] == "SANDBOX") {
				$sandboxParams = "readonly";
			}
			$content = $this->h->input("hidden","cat",$dat['ID']);
			$content .= $this->h->input("hidden","update",1);
			$params =  ($dat['HIDE'])?" checked=\"checked\"":null;
            $content .= $this->h->p( $this->tr->w("sub page of").$this->tree->pathsSelect($dat['PARENTID']) );
			$content .= $this->h->p($this->tr->w("hide").$this->h->input("checkbox","hide","on",$params));
			$content .= $this->h->p($this->tr->w("title")).$this->h->p($this->h->input("text","name",$dat['NAME'],$sandboxParams." size=".FIELDWIDTH));
			$content .= $this->h->p($this->tr->w("description")).$this->h->p($this->h->textarea($dat['DESCRIPTION'],"description",array(8,FIELDWIDTH)));
			$content .= $this->h->p($this->h->input("submit","save",$this->tr->w("update")));
			$result = $this->h->form($content,"page","post","admin.php?action=modify_page");
			return $result;
		}
	}
}
?>
